;script = trklib.sc
; 9/3/91
;
;  This script makes a procedure library called TRACKLB that contains the
;  following procedures:
;             ENTRYMS1   -  Initial Entry of manuscript into system
;             QMENU1     -  Menu for types of queries/retrievals possible--BIB
;               QUBEG2   -  Retrieval by BG number
;               QUREPT1  -  Retrieval by report number
;               QUAUTH2  -  Retrieval by last name of author,primary or other
;               QUPROJ1  -  Retrieval by project number
;               QUPROG1  -  Retrieval by program name
;               QUTYPE1  -  Retrieval by type of manuscript
;               QUCTR1   -  Retrieval by date sent to CTR
;               QUALL1   -  Retrieval of all manuscripts in active database
;             QARCH1     -  Menu for types of queries possible -- ARCH
;               QABEG2   -  Retrieval by BG number -- ARCH
;               QAREPT1  -  Retrieval by report number -- ARCH
;               QAAUTH2  -  Retrieval by last name of author -- ARCH
;               QAPROJ1  -  Retrieval by project number -- ARCH
;               QAPROG1  -  Retrieval by program name  -- ARCH
;               QATYPE1  -  Retrieval by type of manuscript -- ARCH
;               QACTR1   -  Retrieval by date sent to CTR -- ARCH
;               QAALL1   -  Retrieval of all manuscripts in archival database
;             UPDMS4     -  Update location of a manuscript
;               FLDIN    -  Checks to see which locations updated
;               LOOK     -  Contains actual locations paired with variable names
;             RMENU1     -  Menu for reviewer manipulation
;               RASIGN1  -  Assign initial reviewer(s) for a manuscript
;               RLIST1   -  Lists reviewers for a given manuscript
;               RADD1    -  Add reviewer(s) for manuscript
;               RHIST1   -  Look at 'type of reports reviewed' histogram
;             EDITMS1    -  Edit information about a manuscript - not location
;             DELMS1     -  Delete a manuscript from the database
;             MAINT1     -  Maintenance functions, copy,sort,purge diary &
;                            histogram; reset prefix, unload database
;             MSREFR1    -  Add official bibliographic entry to table REF
;             MOV2AR1    -  Moves info about ms from BIB (active) table to
;                             ARCH (archival) table
;
CREATELIB "TRACKLB"
;**********************************
PROC ENTRYMS1()
; 11/14/90
; lookup from table bnum (the prefix) and rnum (last number used) & computes
; the next value for begno - a three digit number with leading zeroes
while (true)
view "bnum"
var1 = [begno] ;puts prefix in var1
clear
view "rnum" ; table that contains next number to be used
var2 = [msnum] ;puts current number in var2
;var3= strval(var2) ; converts integer to character
;var4 = var1 + var3 ; concatenates prefix and number
;clear
;  The extra substr and concat is necessary because the result of the
;  first one is BG9- 009; the extra one takes out the extra space.
;  For explanation of the formatting in the next statement, p. 64 PAL
;
var3= strval(format("w4,ez",var2)); converts integer to character
var4 = var1 + var3 ; concatenates prefix and number
var5 = substr(var4,6,3)
var6 =var1+var5
clear
;message  "The next BG number is:  ", var6
;sleep 1500
; SHOW INITIAL ENTRY FORM AND HAVE USER FILL IN
edit "bib"
     pickform 3
     end
     ctrlpgdn
     [beg_no] = var6
     wait record
         prompt "Press [F2] when done or [esc] to abort"
              until "F2" ,"esc"
              if retval = "F2" or retval = "enter"
;                    fill in 'to review committee' with today's date
                     then
;                    [loc1in] = today()
                     Do_it!
                     clearall
                     menu {modify} {edit}
                     select "rnum" ;table contains next number to be used
                     [msnum] = [msnum] + 1
                     do_it!
;  Diary notation
                     print file "diaryms" today(),"  ",var6,
                        " entered into system--to review committee \n"
                     clearall
                     quitloop
               endif
                     if retval = "esc"
                     then
                         canceledit
                         clear
                         clearall
                         quitloop
                      endif
endwhile
ENDPROC

WRITELIB "TRACKLB" ENTRYMS1
RELEASE PROCS ENTRYMS1
;**********************************
PROC QMENU1()
private x
;8/29/91
;   Menu for different types of queries that can be done
;   on table BIB
;
  x = "BG number"
  while (TRUE)
    Clear
    style attribute 32
    ShowMenu
        "BG number":  "Find manuscript(s) by BG number",
        "Rpt number":  "Find manuscript(s) by report number",
        "Author": "Find manuscript(s) by author name",
        "Project": "Find manuscript(s) by project number",
        "Program": "Find manuscript(s) by program",
        "Type":  "Find manuscript(s) by type of manuscript",
        "CTR":  "List all manuscripts to CTR in given timeframe",
        "List all": "List all manuscripts in database",
        "Return":  "Return to previous menu level"
      Default x
      To x
    switch
      case x = "BG number":
        ReadLib "TRACKLB" QUBEG2
        qubeg2()
        Release Procs QUBEG2
      case x = "Rpt number":
        ReadLib "TRACKLB" QUREPT1
        qurept1()
        Release Procs QUREPT1
      case x = "Author":
        ReadLib "TRACKLB" QUAUTH2
        quauth2()
        Release Procs QUAUTH2
      case x = "Project":
        ReadLib "TRACKLB" QUPROJ1
        quproj1()
        Release Procs QUPROJ1
      case x = "Program":
        ReadLib "TRACKLB" QUPROG1
        quprog1()
        Release Procs QUPROG1
      case x = "Type":
        ReadLib "TRACKLB" QUTYPE1
        qutype1()
        Release Procs QUTYPE1
      case x = "CTR":
        ReadLib "TRACKLB" QUCTR1
        quctr1()
        Release Procs QUCTR1
      case x = "List all":
        ReadLib "TRACKLB" QUALL1
        quall1()
        Release Procs QUALL1
      case x = "Return":
         clearimage
         return
      case x = "Esc":
         clearimage
         return
     endswitch
 endwhile
ENDPROC

WRITELIB "TRACKLB" QMENU1
RELEASE PROCS QMENU1
;****************************************
PROC QUBEG2()
;2/21/91
;  This routine does not use the QUERY command, but is placed in this
;  section because it logically falls here.
while (true)
    style attribute 32
;   GET BEG_NUMBER
    @0,0 ?"QUERY by BG number:  Enter BG number:  "
    accept "a5" to bno
       if isblank(bno) then
           clearall
           return
       else
           begno="BG"+bno
       endif
    view "BIB"
    moveto field "beg_no"
    locate begno
         if not (retval) then
              style attribute 13
              @6,0 ?  "*** ",begno," does not exist in database"
              sleep 3000
              clearall
              loop
         endif
    pickform 1
    wait table
    prompt "Press [F2] when done viewing"
      until "F2"
    if retval = "Esc" or retval = "F2" then
      clear
      clearall
      return
    endif
endwhile

ENDPROC

WRITELIB "TRACKLB" QUBEG2
RELEASE PROCS QUBEG2
;****************************************
PROC QUREPT1()
;2/21/91
;  This routine does not use the QUERY command, but is placed in this
;  section because it logically falls here.
while (true)
    style attribute 32
;   GET REPORT NUMBER
    @0,0 ?"Enter report number (return to exit) :  "
    accept "a10" to rptno
       if isblank(rptno) then
           clearall
           return
       endif
    view "BIB"
    moveto field "report_no"
    locate rptno
         if not (retval) then
              style attribute 13
              @6,0 ?  "*** ",rptno," does not exist in database"
              sleep 3000
              clearall
              loop
         endif
    pickform 1
    wait table
    prompt "Press [F2] when done viewing"
      until "F2"
    if retval = "Esc" or retval = "F2" then
      clear
      clearall
      return
    endif
endwhile

ENDPROC

WRITELIB "TRACKLB" QUREPT1
RELEASE PROCS QUREPT1
;******************************

PROC QUAUTH2()
;8/30/91
;  This retrieves all manuscripts in the database whose primary author, or
;  one of remaining authors has the last name (or close) to that entered
;  by user.  There is a submenu asking which author(s). This information
;  is listed to the screen (use down arrow) and can be printed on a report.
   clear
   style attribute 13
   ShowMenu
         "Primary author":  "Only main author",
         "Additional authors":  "Only search secondary authors",
         "Either":  "Either main or secondary author",
         "Return": "Return to previous menu level"
   Default "Return"
   To v
   if v <> "Return" then
      auth1=" "
      @10,1 ? "Enter author's last name:  "
      accept "a30" to auth1
      if isblank(auth1) then
          clearall
          return
      endif
   endif
   switch
; ++++++++++++++++++++++++++++++++++
      case v = "Primary author":
;++++++++++++++++++++++++++++++++++++
Query

 BIB  | Beg_no | Author1       |Authorrem |  Type |Proj | Prog | Titlelong1 |
      | Check  |Check ~auth1.. |Check     | Check |Check|Check | Check      |
      |        |               |          |       |     |      |            |
      |        |               |          |       |     |      |            |

 BIB  | Loc6in   |
      |Check     |
      |          |
      |          |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees
; +++++++++++++++++++++++++++++++++++++
      case v = "Additional authors":
; ++++++++++++++++++++++++++++++++++++
Query

BIB  | Beg_no | Author1 |     Authorrem     |  Type  |
     | Check  | Check   | Check  ..~auth1.. | Check  |
     |        |         |                   |        |
     |        |         |                   |        |

BIB  |  Proj  |  Prog  | Titlelong1   | Loc6in |
     | Check  | Check  | Check        | Check  |
     |        |        |              |        |
     |        |        |              |        |

Endquery
setqueryorder imageorder

do_it!

upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

;++++++++++++++++++++++++++++
      case v = "Either":
;+++++++++++++++++++++++++++++
Query

BIB  | Beg_no |      Author1      |     Authorrem     |
     | Check  | Check ..~auth1..  | Check             |
     | Check  | Check             | Check ..~auth1..  |
     |        |                   |                   |

BIB  |  Type  |  Proj  |  Prog  | Titlelong1 |
     | Check  | Check  | Check  | Check      |
     | Check  | Check  | Check  | Check      |
     |        |        |        |            |

BIB  | Loc6in |
     | Check  |
     | Check  |
     |        |

Endquery
setqueryorder imageorder

do_it!

upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

;+++++++++++++++++++++++++++
      case v = "Return":
              clear
              clearall
      case v = "Esc":
              clearall
              return
   endswitch

if not (istable("answer")) then
   style attribute 13
   @6,0 ?  auth1," was not found in this database."
        sleep 2000
   else
;     The temporary ANSWER table is renamed to "CTR" so that it doesn't
;       get overwritten inadvertently.  The table "JCTR" has the exact
;       same structure as the answer ("CTR") table.  It and its forms
;       and reports exist so that the forms and reports may be copied
;       to the table "CTR".  Tables that get overwritten (like CTR does
;       when ANSWER is renamed) have their forms and reports get
;       overwritten also.  Since the ANSWER table doesn't have forms and
;       reports, then the CTR table doesn't have forms and reports.
;       That is why JCTR exists and its forms and reports are copied
;       to CTR after the query is performed.  The JCTR table and the
;       table created by the query in any of the query modules QUAUTH1,
;       QUPROG1, QUPROJ1, QUCTR1 must be exactly the same.
;       That is why the JCTR table does not have a key item.
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 4 "ctr" 4
      copyform   "jctr" 4 "ctr" 4
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb," manuscripts by ",auth1
        sleep 2000
      view "ctr"
      if not isempty("ctr") then
        pickform 4
        wait table
;          To see the results of the query on the screen a FORM must be used
;          To see the results of the query on the printer a REPORT must be used
;          The down arrow allows the person viewing the results on the screen
;             to go to the next manuscript - this SEEMS to work with only one
;             keystroke only when all the fields except the last one are
;             displayonly.

      prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
          until "F2", "Esc", "F7"
          if retval = "Esc"
           then quit
          endif
          if retval = "F7" then
            report "ctr" "4"
          endif
          if retval = "down" then
            DOWN
          endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QUAUTH2
RELEASE PROCS QUAUTH2
;*****************************

PROC QUPROJ1()
;8/30/91
;  This procedure retrieves all manuscripts having project numbers matching
;    the one entered by the user.  These manuscripts are listed to the
;    screen (use down arrow) and can be printed on a report.
;
style attribute 32
@5,1 ?"Enter project number to retrieve:  "
accept "a13"  to proj1
   if isblank(proj1)
   then
       clearall
       return
   endif

Query

BIB   | Beg_no | Author1|Authorrem |  Type|Proj          | Prog | Titlelong1|
      | Check  | Check  |Check     | Check|Check ~proj1..|Check | Check     |
      |        |        |          |      |              |      |           |
      |        |        |          |      |              |      |           |

BIB   | Loc6in |
      |Check   |
      |        |
      |        |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @6,0 ?  proj1," was not found in this database."
        sleep 2000
   else
;     See explanation of ANSWER, CTR and JCTR in the QUAUTH2 procedure
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 2 "ctr" 2
      copyform   "jctr" 2 "ctr" 2
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb," manuscripts for project:   ",proj1
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 2
        wait table
;          See explanation of form/report in the QUAUTH2 procedure

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "2"
        endif
        if retval = "down" then
          DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QUPROJ1
RELEASE PROCS QUPROJ1

;************************

PROC QUPROG1()
;8/30/91
;  This procedure retrieves all manuscripts whose program matches that
;  entered by the user.  These manuscripts are listed on the screen (use
;  down arrow) and can be printed on a report.
;
style attribute 32
@10,1 ?"Enter program to retrieve:  "
accept "a6" lookup "pgms" to prog
   if isblank(prog)
   then
       clearall
       return
   endif

Query

BIB   |Beg_no| Author1|Authorrem |  Type  |Proj | Prog       | Titlelong1  |
      |Check | Check  |Check     | Check  |Check|Check ~prog | Check       |
      |      |        |          |        |     |            |             |
      |      |        |          |        |     |            |             |

BIB   | Loc6in |
      |Check   |
      |        |
      |        |

Endquery
setqueryorder imageorder
do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @ 6,0 ?  prog," was not found in this database."
        sleep 2000
   else
;     See explanation of the ANSWER, JCTR, and CTR tables in QUAUTH2 procedure.
      if istable ("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 3 "ctr" 3
      copyform   "jctr" 3 "ctr" 3
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb," manuscripts for program:  ",prog
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 3
        wait table
;          See explanation of form/report in the QUAUTH2 procedure.

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "3"
        endif
        if retval = "down" then
          DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QUPROG1
RELEASE PROCS QUPROG1
; *****************************

PROC QUTYPE1()
;8/30/91
;  This retrieves all manuscripts in the database who are the TYPE of
;  report that is requested by user.  This information
;  is listed to the screen (use down arrow) and can be printed on a report.

@10,1 ?"Enter type of report (AB,AD,BU,CI,PP,MF,OF,OS,CD) : "
accept "a2" lookup "reports" to tor
   if isblank(tor)
   then
       clearall
       return
   endif

Query

BIB   |Beg_no | Author1|Authorrem |  Type      |Proj | Prog |  Titlelong1 |
      |Check  |Check   |Check     | Check ~tor |Check|Check |  Check      |
      |       |        |          |            |     |      |             |
      |       |        |          |            |     |      |             |

BIB   | Loc6in   |
      |Check     |
      |          |
      |          |

Endquery
setqueryorder imageorder

do_it!

upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @6,0 ?  "There are no ",tor," reports in this database."
        sleep 2000
   else
;     The temporary ANSWER table is renamed to "CTR" so that it doesn't
;       get overwritten inadvertently.  The table "JCTR" has the exact
;       same structure as the answer ("CTR") table.  It and its forms
;       and reports exist so that the forms and reports may be copied
;       to the table "CTR".  Tables that get overwritten (like CTR does
;       when ANSWER is renamed) have their forms and reports get
;       overwritten also.  Since the ANSWER table doesn't have forms and
;       reports, then the CTR table doesn't have forms and reports.
;       That is why JCTR exists and its forms and reports are copied
;       to CTR after the query is performed.  The JCTR table and the
;       table created by the query in any of the query modules QUAUTH2,
;       QUPROG1, QUPROJ1, QUCTR1 must be exactly the same.
;       That is why the JCTR table does not have a key item.
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 5 "ctr" 5
      copyform   "jctr" 5 "ctr" 5
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb,"  ",tor, "  manuscripts "
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 5
        wait table
;       To see the results of the query on the screen a FORM must be used
;       To see the results of the query on the printer a REPORT must be used
;       The down arrow allows the person viewing the results on the screen
;          to go to the next manuscript - this SEEMS to work with only one
;          keystroke only when all the fields except the last one are
;          displayonly.

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "5"
        endif
        if retval = "down" then
           DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QUTYPE1
RELEASE PROCS QUTYPE1
;***********************************
PROC QUCTR1()
; 8/27/91
;  This procedure retrieves all manuscripts whose date in "loc6in" (to CTR)
;   falls between the minimum and maximum dates entered (including the min
;   and max dates).  This information is listed to the screen (use down
;   arrow) and can be printed to a report.  The reports are sorted by program.
;
style attribute 10

@0,0 ?"Manuscripts sent to CTR"
style attribute 32
@2,0 ?"Enter minimum date      :  "
accept "d" to date1
   if isblank(date1)
   then
       clearall
       return
   endif
@3,0 ?"Enter maximum date      :  "
accept "d" to date2
    if isblank(date2)
    then
      clearall
      return
    endif

Query

BIB   | Beg_no| Author1|Authorrem |  Type  |Proj | Prog |  Titlelong1  |
      | Check | Check  |Check     | Check  |Check|Check |  Check       |
      |       |        |          |        |     |      |              |
      |       |        |          |        |     |      |              |

BIB   | Loc6in                 |
      |Check >=~date1,<=~date2 |
      |                        |
      |                        |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @ 6,0 ? " No manuscripts to CTR between ",date1," and ",date2
        sleep 2000
   else
;     See explanation in QUAUTH2 for ANSWER/CTR/JCTR tables.
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 6 "ctr" 6
      copyform   "jctr" 1 "ctr" 1
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb,
                " manuscripts to CTR between ",date1," and ",date2
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 1
        wait table
;          See explanation in QUAUTH2 for form/report discussion.

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "6"
        endif
        if retval = "down" then
          DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QUCTR1
RELEASE PROCS QUCTR1
;***********************************

PROC QUALL1()
;2/21/91
;  This procedure retrieves all manuscripts in the active database BIB
;   and lists them to the screen in table form.
Query

BIB   | Beg_no | Author1       |  Type  |Proj | Prog |  Titlelong1     |
      | Check  | Check         | Check  |Check|Check |  Check          |
      |        |               |        |     |      |                 |
      |        |               |        |     |      |                 |

BIB   |
      |
      |
      |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @ 6,0 ?  "There are no manuscripts in this database."
        sleep 2000
   else
      wait table
      prompt "Press [F2] when done viewing; press ALT [F5] to see long fields"
        until "F2", "Esc"
        if retval = "Esc"
           then return
        endif
endif
ENDPROC

WRITELIB "TRACKLB" QUALL1
RELEASE PROCS QUALL1
; *******************************
PROC QARCH1()
private x
;8/29/91
;   Menu for different types of queries that can be done on table ARCH
;   this corresponds to QMENU1 for BIB table
;   and all modules correspond to similar modules under QMENU
;
  x = "BG number"
  while (TRUE)
    Clear
    style attribute 32
    ShowMenu
        "BG number": "Find manuscript(s) by BG number",
        "Rpt number":  "Find manuscript(s) by report number",
        "Author": "Find manuscript(s) by author name",
        "Project": "Find manuscript(s) by project number",
        "Program": "Find manuscript(s) by program",
        "Type":  "Find manuscript(s) by type of manuscript",
        "CTR":  "List all manuscripts to CTR in given timeframe",
        "List all": "List all manuscripts in database",
        "Return":  "Return to previous menu level"
      Default x
      To x
    switch
      case x = "BG number":
        ReadLib "TRACKLB" QABEG2
        qabeg2()
        Release Procs QABEG2
      case x = "Rpt number":
        ReadLib "TRACKLB" QAREPT1
        qarept1()
        Release Procs QAREPT1
      case x = "Author":
        ReadLib "TRACKLB" QAAUTH2
        qaauth2()
        Release Procs QAAUTH2
      case x = "Project":
        ReadLib "TRACKLB" QAPROJ1
        qaproj1()
        Release Procs QAPROJ1
      case x = "Program":
        ReadLib "TRACKLB" QAPROG1
        qaprog1()
        Release Procs QAPROG1
      case x = "Type":
        ReadLib "TRACKLB" QATYPE1
        qatype1()
        Release Procs QATYPE1
      case x = "CTR":
        ReadLib "TRACKLB" QACTR1
        qactr1()
        Release Procs QACTR1
      case x = "List all":
        ReadLib "TRACKLB" QAALL1
        qaall1()
        Release Procs QAALL1
      case x = "Return":
         clearimage
         return
      case x = "Esc":
         clearimage
         return
     endswitch
 endwhile
ENDPROC

WRITELIB "TRACKLB" QARCH1
RELEASE PROCS QARCH1
;****************************************
PROC QABEG2()
;2/21/91
;  This routine does not use the QUERY command, but is placed in this
;  section because it logically falls here.
while (true)
    style attribute 32
;   GET BEG_NUMBER
    @0,0 ?"QUERY by BG number:  Enter BG number:  "
    accept "a5" to bno
       if isblank(bno) then
           clearall
           return
       else
           begno="BG"+bno
       endif
    view "ARCH"
    moveto field "beg_no"
    locate begno
         if not (retval) then
              style attribute 13
              @6,0 ?  "*** ",begno," does not exist in database"
              sleep 3000
              clearall
              loop
         endif
    pickform 1
    wait table
    prompt "Press [F2] when done viewing"
      until "F2"
    if retval = "Esc" or retval = "F2" then
      clear
      clearall
      return
    endif
endwhile

ENDPROC

WRITELIB "TRACKLB" QABEG2
RELEASE PROCS QABEG2
;****************************************
PROC QAREPT1()
;2/21/91
;  This routine does not use the QUERY command, but is placed in this
;  section because it logically falls here.
while (true)
    style attribute 32
;   GET REPORT NUMBER
    @0,0 ?"Enter report number (return to exit) :  "
    accept "a10" to rptno
       if isblank(rptno) then
           clearall
           return
       endif
    view "ARCH"
    moveto field "report_no"
    locate rptno
         if not (retval) then
              style attribute 13
              @6,0 ?  "*** ",rptno," does not exist in database"
              sleep 3000
              clearall
              loop
         endif
    pickform 1
    wait table
    prompt "Press [F2] when done viewing"
      until "F2"
    if retval = "Esc" or retval = "F2" then
      clear
      clearall
      return
    endif
endwhile

ENDPROC

WRITELIB "TRACKLB" QAREPT1
RELEASE PROCS QAREPT1
;******************************

PROC QAAUTH2()
;8/30/91
;  This retrieves all manuscripts in the database whose primary author, or
;  one of remaining authors has the last name (or close) to that entered
;  by user.  There is a submenu asking which author(s). This information
;  is listed to the screen (use down arrow) and can be printed on a report.
   clear
   style attribute 13
   ShowMenu
         "Primary author":  "Only main author",
         "Additional authors":  "Only search secondary authors",
         "Either":  "Either main or secondary author",
         "Return": "Return to previous menu level"
   Default "Return"
   To v
   if v <> "Return" then
      auth1=" "
      @10,1 ? "Enter author's last name:  "
      accept "a30" to auth1
      if isblank(auth1) then
          clearall
          return
      endif
   endif
   switch
; ++++++++++++++++++++++++++++++++++
      case v = "Primary author":
;++++++++++++++++++++++++++++++++++++
Query

 ARCH | Beg_no | Author1       |Authorrem |  Type |Proj | Prog | Titlelong1 |
      | Check  |Check ~auth1.. |Check     | Check |Check|Check | Check      |
      |        |               |          |       |     |      |            |
      |        |               |          |       |     |      |            |

 ARCH | Loc6in   |
      |Check     |
      |          |
      |          |

Endquery
setqueryorder imageorder

do_it!

upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees
; +++++++++++++++++++++++++++++++++++++
      case v = "Additional authors":
; ++++++++++++++++++++++++++++++++++++
Query


ARCH | Beg_no | Author1 |     Authorrem     |  Type  |
     | Check  | Check   | Check  ..~auth1.. | Check  |
     |        |         |                   |        |
     |        |         |                   |        |

ARCH |  Proj  |  Prog  | Titlelong1   | Loc6in |
     | Check  | Check  | Check        | Check  |
     |        |        |              |        |
     |        |        |              |        |

Endquery
setqueryorder imageorder

do_it!

upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

;++++++++++++++++++++++++++++
      case v = "Either":
;+++++++++++++++++++++++++++++
Query

ARCH | Beg_no |      Author1      |     Authorrem     |
     | Check  | Check ..~auth1..  | Check             |
     | Check  | Check             | Check ..~auth1..  |
     |        |                   |                   |

ARCH |  Type  |  Proj  |  Prog  | Titlelong1 |
     | Check  | Check  | Check  | Check      |
     | Check  | Check  | Check  | Check      |
     |        |        |        |            |

ARCH | Loc6in |
     | Check  |
     | Check  |
     |        |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

;+++++++++++++++++++++++++++
      case v = "Return":
              clear
              clearall
      case v = "Esc":
              clearall
              return
   endswitch

if not (istable("answer")) then
   style attribute 13
   @6,0 ?  auth1," was not found in this database."
        sleep 2000
   else
;     The temporary ANSWER table is renamed to "CTR" so that it doesn't
;       get overwritten inadvertently.  The table "JCTR" has the exact
;       same structure as the answer ("CTR") table.  It and its forms
;       and reports exist so that the forms and reports may be copied
;       to the table "CTR".  Tables that get overwritten (like CTR does
;       when ANSWER is renamed) have their forms and reports get
;       overwritten also.  Since the ANSWER table doesn't have forms and
;       reports, then the CTR table doesn't have forms and reports.
;       That is why JCTR exists and its forms and reports are copied
;       to CTR after the query is performed.  The JCTR table and the
;       table created by the query in any of the query modules QUAUTH1,
;       QUPROG1, QUPROJ1, QUCTR1 must be exactly the same.
;       That is why the JCTR table does not have a key item.
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 4 "ctr" 4
      copyform   "jctr" 4 "ctr" 4
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb," manuscripts by ",auth1
        sleep 2000
      if not isempty("ctr")  then
        view "ctr"
        pickform 4
        wait table
;       To see the results of the query on the screen a FORM must be used
;       To see the results of the query on the printer a REPORT must be used
;       The down arrow allows the person viewing the results on the screen
;       to go to the next manuscript - this SEEMS to work with only one
;       keystroke only when all the fields except the last one are
;       displayonly.

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "4"
        endif
        if retval = "down" then
            DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QAAUTH2
RELEASE PROCS QAAUTH2

;*****************************

PROC QAPROJ1()
;8/30/91
;  This procedure retrieves all manuscripts having project numbers matching
;    the one entered by the user.  These manuscripts are listed to the
;    screen (use down arrow) and can be printed on a report.
;
style attribute 32
@5,1 ?"Enter project number to retrieve:  "
accept "a13"  to proj1
   if isblank(proj1)
   then
       clearall
       return
   endif

Query

ARCH  |Beg_no | Author1|Authorrem |  Type|Proj          | Prog | Titlelong1|
      |Check  | Check  |Check     | Check|Check ~proj1..|Check | Check     |
      |       |        |          |      |              |      |           |
      |       |        |          |      |              |      |           |

ARCH  | Loc6in |
      |Check   |
      |        |
      |        |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @6,0 ?  proj1," was not found in this database."
        sleep 2000
   else
;     See explanation of ANSWER, CTR and JCTR in the QUAUTH2 procedure
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 2 "ctr" 2
      copyform   "jctr" 2 "ctr" 2
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb," manuscripts for project:   ",proj1
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 2
        wait table
;          See explanation of form/report in the QUAUTH2 procedure

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "2"
        endif
        if retval = "down" then
           DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QAPROJ1
RELEASE PROCS QAPROJ1

;************************

PROC QAPROG1()
;8/30/91
;  This procedure retrieves all manuscripts whose program matches that
;  entered by the user.  These manuscripts are listed on the screen (use
;  down arrow) and can be printed on a report.
;
style attribute 32
@10,1 ?"Enter program to retrieve:  "
accept "a6" lookup "pgms" to prog
   if isblank(prog)
   then
       clearall
       return
   endif

Query

ARCH  | Beg_no| Author1|Authorrem | Type  |Proj | Prog       | Titlelong1  |
      | Check | Check  |Check     |Check  |Check|Check ~prog | Check       |
      |       |        |          |       |     |            |             |
      |       |        |          |       |     |            |             |

ARCH  | Loc6in |
      |Check   |
      |        |
      |        |

Endquery
setqueryorder imageorder
do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @ 6,0 ?  prog," was not found in this database."
        sleep 2000
   else
;   See explanation of the ANSWER, JCTR, and CTR tables in QUAUTH2 procedure.
      if istable ("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 3 "ctr" 3
      copyform   "jctr" 3 "ctr" 3
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb," manuscripts for program:  ",prog
        sleep 2000
      if not isempty("ctr") then
        view "ctr"
        pickform 3
        wait table
;          See explanation of form/report in the QUAUTH2 procedure.

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "3"
        endif
        if retval = "down" then
           DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QAPROG1
RELEASE PROCS QAPROG1
; *****************************

PROC QATYPE1()
;8/30/91
;  This retrieves all manuscripts in the database who are the TYPE of
;  report that is requested by user.  This information
;  is listed to the screen (use down arrow) and can be printed on a report.

@10,1 ?"Enter type of report (AB,AD,BU,CI,PP,MF,OF,OS,CD) : "
accept "a2" lookup "reports" to tor
   if isblank(tor)
   then
       clearall
       return
   endif

Query

ARCH  | Beg_no | Author1|Authorrem |  Type      |Proj | Prog |  Titlelong1 |
      | Check  |Check   |Check     | Check ~tor |Check|Check |  Check      |
      |        |        |          |            |     |      |             |
      |        |        |          |            |     |      |             |

ARCH  | Loc6in   |
      |Check     |
      |          |
      |          |

Endquery
setqueryorder imageorder

do_it!

upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @6,0 ?  "There are no ",tor," reports in this database."
        sleep 2000
   else
;     The temporary ANSWER table is renamed to "CTR" so that it doesn't
;       get overwritten inadvertently.  The table "JCTR" has the exact
;       same structure as the answer ("CTR") table.  It and its forms
;       and reports exist so that the forms and reports may be copied
;       to the table "CTR".  Tables that get overwritten (like CTR does
;       when ANSWER is renamed) have their forms and reports get
;       overwritten also.  Since the ANSWER table doesn't have forms and
;       reports, then the CTR table doesn't have forms and reports.
;       That is why JCTR exists and its forms and reports are copied
;       to CTR after the query is performed.  The JCTR table and the
;       table created by the query in any of the query modules QUAUTH2,
;       QUPROG1, QUPROJ1, QUCTR1 must be exactly the same.
;       That is why the JCTR table does not have a key item.
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 5 "ctr" 5
      copyform   "jctr" 5 "ctr" 5
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb,"  ",tor, "  manuscripts "
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 5
        wait table
;       To see the results of the query on the screen a FORM must be used
;       To see the results of the query on the printer a REPORT must be used
;       The down arrow allows the person viewing the results on the screen
;          to go to the next manuscript - this SEEMS to work with only one
;          keystroke only when all the fields except the last one are
;          displayonly.

      prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "5"
        endif
        if retval = "down" then
           DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QATYPE1
RELEASE PROCS QATYPE1
;***********************************
PROC QACTR1()
; 8/30/91
;  This procedure retrieves all manuscripts whose date in "loc6in" (to CTR)
;   falls between the minimum and maximum dates entered (including the min
;   and max dates).  This information is listed to the screen (use down
;   arrow) and can be printed to a report.  The manuscripts are grouped by
;   program type on the report.

style attribute 10

@0,0 ?"Manuscripts sent to CTR"
style attribute 32
@2,0 ?"Enter minimum date      :  "
accept "d" to date1
   if isblank(date1)
   then
       clearall
       return
   endif
@3,0 ?"Enter maximum date      :  "
accept "d" to date2
    if isblank(date2)
    then
      clearall
      return
    endif

Query

ARCH  | Beg_no | Author1|Authorrem |  Type  |Proj | Prog |  Titlelong1  |
      | Check  | Check  |Check     | Check  |Check|Check |  Check       |
      |        |        |          |        |     |      |              |
      |        |        |          |        |     |      |              |

ARCH  | Loc6in                 |
      |Check >=~date1,<=~date2 |
      |                        |
      |                        |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @ 6,0 ? " No manuscripts to CTR between ",date1," and ",date2
        sleep 2000
   else
;     See explanation in QUAUTH2 for ANSWER/CTR/JCTR tables.
;
      if istable("ctr") then
         delete "ctr"
      endif
      rename "answer"  "ctr"
      copyreport "jctr" 6 "ctr" 6
      copyform   "jctr" 1 "ctr" 1
        numb = nrecords ("ctr")
        style attribute 13
        @12,0 ? "        ",numb,
                " manuscripts to CTR between ",date1," and ",date2
        sleep 2000
      if not isempty ("ctr") then
        view "ctr"
        pickform 1
        wait table
;          See explanation in QUAUTH2 for form/report discussion.

    prompt "Press [F2] when done viewing; Press ALT [F5] to see long fields",
             "Press [down] to see next entry;  Press [F7] to print a report"
        until "F2", "Esc", "F7"
        if retval = "Esc"
           then quit
        endif
        if retval = "F7" then
           report "ctr" "6"
        endif
        if retval = "down" then
           DOWN
        endif
      endif
endif
clearall
ENDPROC

WRITELIB "TRACKLB" QACTR1
RELEASE PROCS QACTR1
;***********************************

PROC QAALL1()
;2/21/91
;  This procedure retrieves all manuscripts in the active database BIB
;   and lists them to the screen in table form.
Query

ARCH  | Beg_no | Author1      |  Type  |Proj | Prog |  Titlelong1     |
      | Check  | Check        | Check  |Check|Check |  Check          |
      |        |              |        |     |      |                 |
      |        |              |        |     |      |                 |

ARCH  |
      |
      |
      |

Endquery
setqueryorder imageorder

do_it!
upimage          ; these two commands remove the query form from the
clearimage       ; screen image the user sees

if (isempty("answer")) then
   style attribute 13
   @ 6,0 ?  "There are no manuscripts in this database."
        sleep 2000
   else
      wait table
      prompt "Press [F2] when done viewing; press ALT [F5] to see long fields"
        until "F2", "Esc"
        if retval = "Esc"
           then return
        endif
endif
ENDPROC

WRITELIB "TRACKLB" QAALL1
RELEASE PROCS QAALL1

;****************************************

 PROC UPDMS4()
;8/29/91
;  This procedure allows the user to "move" a manuscript from one location
;    to another.  A 'routing sheet' form is used.  (loc10out) is the
;    last location to be used; locs 11,12,13, and 14 are not used at this
;    time.  Loc15in is the date of bibliographic entry.  That date is
;    put in through the bibliography selection, not the update selection.

;    This routine stores the last location that had a date when the update
;    routine was entered (LASTVAR).  After the update process
;    is completed (do_it!), the routine FLDIN interrogates the database
;    and sees what locations (after LASTVAR) have dates.  It makes the
;    assumptions that the users will not update to a location before
;    the LASTVAR location.  It uses the routine LOOK to attach names of
;    places to the location positions and makes the entry in the diary.
;
;    If loc6out (CTR/Director's Approval) was given a date, the routine FLDIN
;    checks to see if the ms is an OF, if it is a prompt is issued for
;    report number.  Report numbers for other types of manuscripts are
;    added in the bibliographic entry section (MSREFR1)

;GET VALUE FOR VARIABLE BEGNO
while(true)
    style attribute 32
    @0,0 ?"LOCATION UPDATE:  Enter BG number: "
    accept "a5" to bno
       if isblank(bno)
         then clearall
              return
       else
          begno="BG"+bno
       endif
     view "bib"
     moveto field "Beg_no"
     LOCATE begno
        if not (retval) then
           style attribute 13
           @6,0 ?  " *** ",begno," does not exist in database "
           sleep 2000
           clearall
           loop
        endif
;    SET VARS FOR LOCATION OF DB FIELDS
     var1="loc"
     var5=11    ; start here because do var5-1 in loop 10 is last active loc
     var3="in"
     var4="out"

;    CHECK TO SEE IF MS HAS loc10out filled in, if so is done routing
     if not (isblank([loc10out])) then  ;loc10out has a date, is not blank
         style attribute 13
         @ 10,0 ? " This manuscript cannot be routed any further"
             sleep 1000
         clearall
         return
     endif

;    MANUSCRIPT IS STILL IN ROUTING SYSTEM
  while(var5 > 0)
;    start looking from end of routing sheet backwards and find last
;    location that has a date recorded (either to or from)
;    set vars for walking backwards up the routing sheet to check for dates
     var5=var5 - 1
     var2=strval(var5)
     varloc= var1 + var2 + var3     ;in
     varloc2=var1 + var2 + var4     ;out
     moveto field varloc2
;       message "HERE1 ",isblank(fieldstr())," ",varloc
;       sleep 2000
        if (isblank(fieldstr()))     ; there is no date recorded
        then
           moveto field varloc
           if (isblank(fieldstr())) then
              loop
           else
              lastvar=varloc
              edit "bib"
              pickform 1
              wait record
                  prompt "Press [F2] when done or [esc] to abort"
                  until "F2", "esc"
              if retval = "F2" then
                  do_it!
                  READLIB "TRACKLB" FLDIN
                  FLDIN()
              endif
              if retval = "esc" then
                  canceledit
                  clearall
                  quitloop
              endif

           endif
        else   ;has date for "from" loc,
           lastvar = varloc2
           edit "bib"
           pickform 1
           wait record
               prompt "Press [F2] when done or [esc] to abort"
               until "F2", "esc"
           if retval = "F2" then
               do_it!
               READLIB "TRACKLB" FLDIN
               FLDIN()
           endif
           if retval = "esc" then
               canceledit
               clearall
               quitloop
           endif
        endif
        quitloop
  endwhile
  clear
  clearall
endwhile

ENDPROC

WRITELIB "TRACKLB" UPDMS4
RELEASE PROCS UPDMS4
;*********************************

PROC FLDIN()
;  1/25/91
; script is called by updms4 after locations have been updated. The locations
; are updated during a wait record, so updms4 does not know which variables
; have been changed.  This routine checks all locations (variables) that
; occur after the last location that had a date when the update function was
; invoked.  It checks all because some locations may be skipped.
; It checks from that point through loc10out.  Locs 11,12,13,14 in/out are not
; currently used in this database and loc15in is a date for the bibliographic
; entry.
;
;  If ms returned from CTR/Dir's approval, checks to see if OF, if so, then
;  prompts for report number and puts in BIB table.

if (substr(lastvar,6,1)<>"o") and (substr(lastvar,5,1)<>"o") then
;    last location with a date was an 'in' location
;    check corresponding 'out' location to see if date was inserted there
     moveto field varloc2
     if not (isblank (fieldstr())) then  ;is a date in correspond 'out' loc
                   vor=substr(varloc2,5,1)
                   if vor = "o" then
                        vor1 = substr(varloc2,4,1)
                   else
                        vor1 = substr(varloc2,4,2)
                   endif
                   READLIB "TRACKLB" LOOK
                   LOOK()
                        print file "diaryms" today(),"  ",begno,
                        " ms from ",locat1,"\n"
                   if locat1 = "CTR/Director's Approval" then
                       if [type] = "OF" then
                          style attribute 32
                          @0,6 ?"Enter open-file report number: "
                          accept "a10" to rptno
                             if isblank(rptno) then
                                clearall
                                return
                             endif
                          edit "bib"
                          [report_no] = rptno
                          do_it!
                       endif
                   endif
     endif
endif

; last location with a date was an 'out' location  OR  last location was
; an 'in' location and the corresponding 'out' location was checked for
; the presence of a date in previous section.  All go thru this section.

var6 = var5
var6 = var6 +1

while (var6 < 11) ;location 11,12,13,14 not used currently, ** hard coded **
     var7 = strval(var6)
     varfil = var1 + var7 + var3  ;  in location
     varfil2 = var1 + var7 + var4 ; out location

     moveto field varfil   ; in location
     if not (isblank (fieldstr())) then       ; has date
                   vor=substr(varfil,5,1)
                   if vor = "i" then
                        vor1 = substr(varfil,4,1)
                   else
                        vor1 = substr(varfil,4,2)
                   endif
                   READLIB "TRACKLB" LOOK
                   LOOK()
                   print file "diaryms" today(),"  ",begno,
                        " ms to ",locat1,"\n"
     endif

     moveto field varfil2  ; out location
     if not (isblank (fieldstr())) then       ; has date
                   vor=substr(varfil2,5,1)
                   if vor = "o" then
                        vor1 = substr(varfil2,4,1)
                   else
                        vor1 = substr(varfil2,4,2)
                   endif
                   READLIB "TRACKLB" LOOK
                   LOOK()
                   print file "diaryms" today(),"  ",begno,
                        " ms from ",locat1,"\n"
     endif
     var6=var6+1
endwhile

ENDPROC

WRITELIB "TRACKLB" FLDIN
RELEASE PROCS FLDIN

; *********************************
PROC LOOK()
;1/25/91
; This procedure matches the database variables with the 'actual' location
; If the routing of the manuscripts changes - the following changes need to
;  be made:  (1)  Change form F1 for BIB, both the description and the field
;  (2) Change this file to agree with form F1 for BIB
; The only 'hard coded' reference to variable names is in QUCTR
;  and UPDMS4 starts looking backwards from loc10in (no location 11,12,13,14)
;(loc15in is biblio entry)
;message var1
;sleep 2000

switch
 case vor1 = "1":    locat1 = "Review Commitee"
 case vor1 = "2":    locat1 = "Reviewers"
 case vor1 = "3":    locat1 = "TPSG"
 case vor1 = "4":    locat1 = "GNU"
 case vor1 = "5":    locat1 = "ABC"
 case vor1 = "6":    locat1 = "CTR/Director's Approval"
 case vor1 = "7":    locat1 = "CTR-repro"
 case vor1 = "8":    locat1 = "Ozalid"
 case vor1 = "9":    locat1 = "clerical-copying"
 case vor1 = "10":   locat1 = "CTR-OFSS"
 case vor1 = "11":   locat1 = "not used"
 case vor1 = "12":   locat1 = "not used"
 case vor1 = "13":   locat1 = "not used"
 case vor1 = "14":   locat1 = "not used"
 case vor1 = "15":   locat1 = "Bibliography"

endswitch

;message locat1
;sleep 2000

ENDPROC

WRITELIB "TRACKLB" LOOK
RELEASE PROCS LOOK

;*********************************
;
PROC RMENU1()
;11/9/90
while (TRUE)
    Clear

  ShowMenu
        "Assign reviewers": "Assign reviewers to manuscript",
        "List reviewers": "List all reviewers for certain manuscript",
        "Add reviewers": "Assign additional reviewer(s) to manuscript",
        "Examine histogram": "Look at DB of reviewers",
        "Return":  "Return to previous menu level"
  Default "List reviewers"
  To x

    switch
      case x = "Assign reviewers":
         ReadLib "TRACKLB" rasign1
         rasign1()
         Release Procs rasign1

      case x = "List reviewers":
         ReadLib "TRACKLB" rlist1
         rlist1()
         Release Procs rlist1

      case x = "Add reviewers":
         ReadLib "TRACKLB" radd1
         radd1()
         Release Procs radd1

      case x = "Examine histogram":
         ReadLib "TRACKLB" rhist1
         rhist1()
         Release Procs rhist1

      case x = "Return":
         clearimage
         return

      case x = "Esc":
         clearimage
         return
     endswitch
endwhile

ENDPROC

WRITELIB "TRACKLB" RMENU1
RELEASE PROCS RMENU1

;******************************************

PROC RASIGN1()
; 1/28/91
array rnames[5]
array mnames[25]
while (TRUE)
  Clear
;      ASSIGN INITIAL REVIEWERS, CANNOT ADD REVIEWERS
;      Gets BG no., goes to the BIB table, displays information about the
;      manuscript and asks if correct manuscript.  If so, gets the
;      report type, and then puts up form for entry of reviewers names
;      Enters reviewers names into REVIEW table; enters reviewer's name
;      into HISTO table and makes entry under 1st available space MS1 - MS25
;      for the type of manuscript reviewed.  If reviewer already exists
;      EXACTLY as entered, only the code for type of manuscript is added.
;
       style attribute 32
       @0,0 ?"ASSIGN REVIEWERS:  Enter BG number: "
       accept "a5" to bno
       if isblank(bno)
          then clearall
             return
       else
             begno="BG"+bno
       endif
       view "bib"
       moveto field "Beg_no"
       locate begno
       if not (retval)
           then message " *** ",begno," does not exist in database "
           sleep 2000
           clearall
           loop
       endif
     pickform 4    ; embedded form
     wait table
     prompt "Press [F2] if this is the correct manuscript",
            "Press [ESC] if this is NOT the correct manuscript"
         until "F2","ESC"
     if retval <> "F2" then
        clear
        clearall
        quitloop
     endif
       rtype=[Type]
       clearall

       edit "review"
          moveto field "beg_no"
          locate begno
          if not (retval) then ;doesn't find this ms in table REVIEW
               pickform "F"
               end
               ctrlpgdn
               [beg_no] = begno
               wait record
                  prompt "Press [F2] when done or [esc] to abort"
                  until "F2" ,"esc"
                  if retval = "esc" then
                     canceledit
                     clearall
                     quitloop
                  endif
                  if retval = "F2"  then
;                     Diary notation
                      print file "diaryms" today(),"  ",begno,
                      " Reviewers assigned   \n"
                      do_it!
                      clearall
;
;                     to get report code for histogram
                      view "reports"
                      moveto field "type"
                      locate rtype
                      mcode = [code]
                      clearall
;
;                     puts reviewers names,report code into histogram
                      view "review"
                      moveto field "beg_no"
                      locate begno          ; ms just assigned
                      rnames[1] = [Rev1]
                      rnames[2] = [Rev2]
                      rnames[3] = [Rev3]
                      rnames[4] = [Rev4]
                      clearimage

                      for i from 1 to 4
                         edit "histo"
                         moveto field "revr"
                         if isblank (rnames[i]) then
                             canceledit
                             quitloop
                         else
                            locate rnames[i]        ; name of i th  reviewer
                            if retval then
;                           reviewer exists in db;look for 1st blank ms1-25
                               for k from 1 to 25
                                      mnames[k] = "MS" + strval(k)
                               endfor
                               j=1
                               while (j < 26)
                                    moveto field mnames[j]
                                    if isblank([]) then
                                        [] = mcode
                                        do_it!
                                        j=27
                                    endif
                                    j=j+1
                               endwhile
                            else   ;  new reviewer
                                end
                                down
                                [revr] = rnames[i] ;= reviewer1
                                [ms1] = mcode
                                do_it!
                            endif
                         endif
                      endfor
                  endif
          else
              clear
              clearall
              style attribute 13
              @ 5,0 ? "There are already reviewers assigned to ",begno
              sleep 2000
              @ 7,0  ? "You should use the ADD REVIEWERS selection."
              sleep 2000
              canceledit
              clearall
          endif
endwhile
ENDPROC

WRITELIB "TRACKLB" RASIGN1
RELEASE PROCS RASIGN1
;
;**********************************

PROC RLIST1()
;1/28/91
; procedure lists all reviewers for given manusript
; uses embedded forms, so displays manuscript information as well as
; reviewers
  while (true)
        style attribute 32
        @0,0 ?"LIST REVIEWERS: Enter BG number: "
        accept "a5" to bno
        if isblank(bno)
           then clearall
              return
        else
              begno="BG"+bno
        endif

        view "bib"
        moveto field "Beg_no"
        locate begno
        if not (retval) then
            style attribute 13
            @ 6,0 ? " *** ",begno," does not exist in database "
            sleep 2000
            clearall
            loop
        endif

        pickform "4"
        wait record
          prompt "Press [F2] when done"
           until "F2"
           if retval = "F2"  then
               clear
               clearall
           endif
   endwhile
ENDPROC

WRITELIB "TRACKLB" RLIST1
RELEASE PROCS RLIST1
;
;**********************************

PROC RADD1()
; 1/28/91
;  This procedure allows user to add reviewers (1 at a time) to a given
;   manuscript.  The same process that is used in rasign1 is used here
;   to add names to the REVIEW table and add manuscript codes and reviewer's
;   names to the HISTO table
;
array rnames[5]
array mnames[25]
while (TRUE)
  Clear
        style attribute 32
        @0,0 ?"ADD REVIEWERS:  Enter BG number: "
        accept "a5" to bno
        if isblank(bno)
           then clearall
              return
        else
              begno="BG"+bno
        endif
;       to get report code for histogram
        view "bib"
        moveto field "Beg_no"
        locate begno
        if not (retval) then
            style attribute 13
            @6,0 ?  " *** ",begno," does not exist in database "
            sleep 2000
            clearall
            loop
        endif
        pickform 4                ;embedded form
        wait table
        prompt "Press [F2] if this is the correct manuscript",
               "Press [ESC] if this is NOT the correct manuscript"
             until "F2","ESC"
        if retval <> "F2" then
           clear
           clearall
           quitloop
        endif
        rtype=[Type]

        clearall

        view "reports"
        moveto field "type"
        locate rtype
        mcode = [code]
        clearall
;
        edit "review"
        moveto field "beg_no"
        locate begno
        if not (retval) then
             style attribute 13
             @6,0 ? "*** ",begno," has not been assigned any reviewers."
             sleep 2000
             canceledit
             clearall
             loop
        endif
        if isblank ([rev2]) then
             firstr = "rev2"
        else
             if isblank ([rev3]) then
                  firstr = "rev3"
             else
                  if isblank ([rev4]) then
                      firstr = "rev4"
                  else
                      style attribute 13
                      @6,0 ? "Four reviewers already assigned."
                      sleep 2000
                      canceledit
                      clearall
                      loop
                  endif
             endif
        endif

      moveto field firstr
      pickform "F"
      wait record
           prompt "Press [F2] when done or [esc] to abort"
           until "F2" ,"esc"
           if retval = "esc" then
              canceledit
              clearall
              quitloop
           endif
           if retval = "F2"  then
;              Diary notation
               print file "diaryms" today(),"  ",begno,
               " Additional reviewers assigned   \n"
               do_it!
               clearall
;
;              puts reviewers names,report code into histogram
               view "review"
               moveto field "beg_no"
               locate begno          ; ms just assigned
               rnames[1] = [Rev1]
               rnames[2] = [Rev2]
               rnames[3] = [Rev3]
               rnames[4] = [Rev4]
               clearimage
;
               rstart = numval(substr(firstr,4,4))
               while rstart <= 4
                  edit "histo"
                  moveto field "revr"
                  if isblank (rnames[rstart]) then
                      canceledit
                      quitloop
                  else
                     locate rnames[rstart]  ; name of i th  reviewer
                     if retval then
;                        reviewer exists in db;look for 1st blank ms1-25
                         for k from 1 to 25
                               mnames[k] = "MS" + strval(k)
                         endfor
                         j=1
                         while (j < 26)
                             moveto field mnames[j]
                             if isblank([]) then
                                 [] = mcode
                                 do_it!
                                 j=27
                             endif
                             j=j+1
                         endwhile
                     else   ;  new reviewer
                         end
                         down
                         [revr] = rnames[rstart] ;= reviewer1
                         [ms1] = mcode
                         do_it!
                     endif
                  endif
                  rstart = rstart + 1
               endwhile
           endif
endwhile
ENDPROC

WRITELIB "TRACKLB" RADD1
RELEASE PROCS RADD1
;
;******************************

PROC RHIST1()
; 9/3/91
; allows user to look at histogram that has record of types of manuscripts
; each reviewer has reviewed
;  the HISTO table is set up to take only 25 manuscripts.  This table
;  should be reset at some interval (each calendar year??)

while (true)
  Clear
  ShowMenu
        "Whole histogram": "Look at entire histogram",
        "Look at one reviewer": "List only one reviewer",
        "Return": "Return to previous menu level"
  To x
  style attribute 32

  switch
     case x = "Whole histogram":
               view "histo"
               pickform "F"
               wait table
                  prompt "Press [F2] when done viewing"  until "F2"
               if retval = "F2" then
                    @0,0 ? "Do you want to print this? "
                    accept "a1" to ians
                    if ians="y" then
                      report "histo" "1"
                    endif
               endif
               clearall
     case x = "Look at one reviewer":
               @0,0 ?"Enter reviewer last name (return to exit) : "
               accept "a30" to revnam
               if isblank(revnam)
                  then clearall
                     return
               endif

               Query

               Histo | Revr           |Ms1  |Ms2  |Ms3  |Ms4  |Ms5  |Ms6  |
                     | Check ~revnam..|Check|Check|Check|Check|Check|Check|
                     |                |     |     |     |     |     |     |
                     |                |     |     |     |     |     |     |

               Histo |Ms7  |Ms8  |Ms9  |Ms10 |Ms11 |Ms12 |Ms13 |Ms14 |
                     |Check|Check|Check|Check|Check|Check|Check|Check|
                     |     |     |     |     |     |     |     |     |
                     |     |     |     |     |     |     |     |     |

               Histo |Ms15 |Ms16 |Ms17 |Ms18 |Ms19 |Ms20 |
                     |Check|Check|Check|Check|Check|Check|
                     |     |     |     |     |     |     |
                     |     |     |     |     |     |     |

               Histo |Ms21 |Ms22 |Ms23 |Ms24 |Ms25 |
                     |Check|Check|Check|Check|Check|
                     |     |     |     |     |     |
                     |     |     |     |     |     |

               Endquery
               setqueryorder imageorder

               do_it!
               upimage          ; these two commands remove the query form
               clearimage       ; from the screen image the user sees

               if (isempty("answer"))
                    then message  revnam," was not found in this database."
                    sleep 2000
               else
                    rename "answer"  "hist2"
                    copyform   "histo" 1 "hist2" 1
                    view "hist2"
                    pickform 1
                    wait table
                    prompt "Press [F2] when done viewing" until "F2"
                    if retval = "F2" then
                         clearall
                         return
                    endif
               endif
     case x ="Return":
              return
  endswitch

endwhile
ENDPROC

WRITELIB "TRACKLB" RHIST1
RELEASE PROCS RHIST1
;******************************

PROC EDITMS1()
; 1/28/91
;  This procedure allows the information about the manuscript to be
;  changed.  This has nothing to do with the location of the manuscript.

;GET VALUE FOR VARIABLE BEGNO
WHILE (true)
    style attribute 32
    @0,0 ?"EDIT MANUSCRIPT:  Enter BG number: "
    accept "a5" to bno
       if isblank(bno)
         then clearall
              return
       else
          begno="BG"+bno
       endif
    view "bib"
    moveto field "Beg_no"
    locate begno
       if not (retval) then
          style attribute 13
          @6,0 ?  " *** ",begno," does not exist in database "
               sleep 2000
               clearall
               loop
       endif
;DISPLAY MANUSCRIPT INFORMATION
     pickform 2
     wait record
         prompt " Press [F2] if this is the correct manuscript;",
                " Press [Esc] if it is not"
         until "F2", "Esc"
         switch
             case retval = "Esc":
                clear
                clearall
                loop
             case retval = "F2":
               WHILE true
                 pickform 2
;SHOW EDIT MANUSCRIPT MENU
                 ShowMenu
                    "Author":  "Primary author",
                    "AddAuthor":  "Additional authors",
                    "Title":  "Title",
                    "AddTitle":  "Additional title",
                    "Type":  "Manuscript type",
                    "Project":  "Project number",
                    "Program":  "Program",
                    "None":  "Don't wish to edit any of these attributes"
                     Default "None"
                  To x

;MOVES TO APPROPRIATE FIELD TO EDIT DEPENDING ON MENU CHOICE
                  switch
                     case x = "Author":  moveto field "Author1"
                     case x = "AddAuthor": moveto field "Authorrem"
                     case x = "Title": moveto field "titlelong1"
                     case x = "AddTitle": moveto field "titlelong2"
                     case x= "Type": moveto field "type"
                     case x = "Project": moveto field "proj"
                     case x= "Program": moveto field "prog"
                     case (x = "Esc") OR (x = "None") :
                        clearall
                        clear
                        quitloop
                   endswitch
                   pickform 2
                   editkey
                   fieldview
                   wait field
                       prompt "Press [F2] when done or [esc] to abort"
                       until "F2" ,"Esc"
                       switch
                           case retval = "F2":  do_it!
;Diary notation
                              print file "diaryms" today(), "  ",begno,
                                " edit on field  ", x, "\n"
                           case retval = "Esc":  canceledit
                                 clear
                                 clearall
                                 quitloop
                       endswitch
              ENDWHILE
         endswitch
ENDWHILE
ENDPROC

WRITELIB "TRACKLB" EDITMS1
RELEASE PROCS EDITMS1

;*******************************

PROC DELMS1()
;1/28/91
;  This procedure deletes a manuscript from the database (BIB)

;GET VALUE FOR VARIABLE BEGNO
while (true)
    style attribute 32
    @0,0 ?"DELETE MANUSCRIPT:  Enter BG number: "
    accept "a5" to bno
       if isblank(bno)
         then clearall
              return
       else
          begno="BG"+bno
       endif
     view "bib"
     moveto field "Beg_no"
     LOCATE begno
       if not (retval) then
          style attribute 13
          @6,0 ?  " *** ",begno," does not exist in database "
          sleep 2000
          clearall
          loop
       endif
;    DISPLAY MANUSCRIPT INFORMATION
     pickform 2
     wait field
         prompt " Do you want to delete this manuscript?  Press [y] or [n] "
         until "y", "n"
            if retval = "y"  then
;             THIS IS THE RIGHT MANUSCRIPT
              edit "bib"
              del
              do_it!
              print file "diaryms" today(), "  ",begno,"  deleted \n"
              clear
            else
              clear
              loop
            endif
endwhile
ENDPROC

WRITELIB "TRACKLB" DELMS1
RELEASE PROCS DELMS1

;**********************************

PROC MAINT1()
;8/27/91
;  The procedure MAINT1 contains maintenance features.
;  The functions necessary for the maintenance of the manuscript
;  tracking system are:
;
; 1. The diary is an ASCII file (DIARYMS) that is created chronologically.
;    When "Diary" option is chosen the following actions take place:
;    a.   The diary file is sorted on the BG number; DIARYBG is created
;    b.   The original diary file (DIARYMS) is renamed with the
;         current date as part of the name.  The next time MSTRACK is
;         executed, a new DIARYMS file will be created.
;    c.   To print the diary files the user must return to DOS.
;         The diary cannot be printed through Paradox (PAL manual,
;         version 3.0,  p. 347 & PC PowerTools p. 845) because it generates
;         the error "Insufficient memory to return to Paradox"
; 2. The histogram is stored as a Paradox data table.
;    When the "Histogram" selection is chosen the following actions
;    take place:
;    a.   The HISTO table is sorted according to the last name of the
;         reviewer.  The original table is overwritten with the
;         sorted table.
;    b.   A PARADOX report is created from the HISTO table and named
;         FRQ with the current date appended to the name.
;    c.   The Paradox table HISTO is emptied.
;    d.   To print the histogram information, the user
;         needs to exit to DOS and print the report file.
; 3. When the 'Reset' option is chosen, the manuscript number sequencing
;    is automatically reset to 1.  Then the user can change the prefix
;    for the manuscript number (BG9-).  The 'year' digit can be changed.
;    The two letter code can also change.
; 4. When the 'Unload' option is chosen the Paradox data tables are
;    converted into ASCII files that
;    could be used to transfer the tracking data to another database
;    management system.  The UNLOAD selection creates ASCII files of
;    all the Paradox tables that contain data.  (There are several
;    'dummy' Paradox tables that are not included in the UNLOAD
;    selection (JCTR and HIST2).  They are used throughout the system
;    for various reasons.  These tables need to exist in Paradox for
;    certain functions to take place properly, but in another DBMS,
;    they may not be necessary.)
;

while (TRUE)
   Clear
   style attribute 13
   ShowMenu
         "Diary": "Sort and rename current diary to keep as history file",
         "Histogram": "Keep current file as history and start new histogram",
         "Reset": "Edit the prefix/year and set number for ms to 1",
         "Unload": "Unload entire database to ASCII files",
         "Return": "Return to previous menu level"
   Default "Return"
   To x
      mo = strval(month(today()))
      yr = strval(year(today()))
      da = strval(day(today()))
      yr2= substr(yr,3,2)
   switch
      case x = "Diary":
           nam = "DIA" + mo + "_" + da + "."  +yr2
           phras6 = "sort /+11 < diaryms > diarybg"
           run phras6

           phras = "rename diaryms " + nam
           run phras
           @7,0 ? "Exit Paradox and print  DIARYBG and ",nam
           sleep 3000
      case x = "Histogram":
            sort "histo" on "revr"
            fnam = "frq" + mo + "_" + yr2 +".rpt"
            menu {report} {output} {histo} {1} {file} {freq}
            phras1 = "ren freq.rpt " + fnam
            run phras1

            empty "histo"
            clear

            @7,0 ? "Exit Paradox and print ",fnam
            sleep 3000
      case x = "Reset":
              edit "rnum"
              [msnum]=1
              do_it!
              @10,0 ? "The sequence has been reset to 1"  sleep 3000
              clear
              @12,0 ? "Enter the new prefix [Ex.  BG5-] :  "
              accept "a4" to prefx
              clear
              edit "bnum"
              [begno] = prefx
              do_it!
              @14,0 ? "The prefix has been changed to ",prefx    sleep 3000
              print file "diaryms" today(),"  Prefix and sequence reset \n"
              sleep 3000
              clear
      case x = "Unload":
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Arch} {arch.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Bib} {bib.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Bnum} {bnum.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Pgms} {pgms.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Ref} {ref.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Reports} {rep.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Review} {rev.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Rnum} {rno.ASC}
              menu {tools} {ExportImport} {Export}
                   {ASCII} {Delimited} {Histo} {histo.ASC}
              print file "diaryms" today(),
                   "  Database unloaded to ASCII files  \n"
              clearall
      case x = "Return":
              clearall
              return
      case x = "Esc":
              clearall
              return
   endswitch
endwhile
ENDPROC

WRITELIB "TRACKLB" MAINT1
RELEASE PROCS MAINT1
; ************************
PROC MSREFR1()
;  8/28/91
;  This procedure allows user to make complete, official bibliographic
;   entry for a manuscript, edit an existing bibliographic entry, or
;   add the official report number of a manuscript.
;   The manuscript must still be active (in BIB table) and must have
;   Director's approval.
;   A manuscript cannot move from BIB to ARCH
;   (archival table) unless the bibliographic entry has been made.

;   The bibliographic entry goes into table REF
;   The field DIRAPP is the same as the field loc6out in table BIB/ARCH
;   The field BRANCHBIBLIO?  is for use when software is developed to pull
;      the information from REF for Branch bibliography.  This will be a
;      flag to indicate when a manuscript has already been included in a
;      branch bibliography
;
;GET VALUE FOR VARIABLE BEGNO
while(true)
style attribute 32
ShowMenu
   "Entry":  "Make bibliographic entry",
   "Change": "Edit existing bibliographic entry",
   "Number": "Add official report number",
   "Return": "Return to main menu"
 to rout
 if rout="Entry" or rout = "Change" or rout = "Number"  then
    @0,0 ?"BIBLIOGRAPHIC REFERENCE/REPT. NO.:  Enter BG number:  "
    accept "a5" to bno
       if isblank(bno)
         then clearall
              return
       else
          begno="BG"+bno
       endif
 endif
switch
 case rout = "Entry":
     view "ref"
     moveto field "Beg_no"
     LOCATE begno
        if (retval) then
           style attribute 13
           @6,0 ?  " *** ",begno," already has bibliographic reference "
           sleep 2000
           clear
           loop
        endif

     edit "bib"
     moveto field "Beg_no"
     locate begno
         if not (retval) then
            style attribute 13
            @6,0 ? " *** ",begno," not in active database"
            sleep 2000
            canceledit
            clear
            loop
         else
            if isblank ([loc6out]) then
               @7,0 ? " *** ",begno," has no director's approval"
               sleep 2000
               canceledit
               clear
               loop
            else
               dirdate = [loc6out]
            endif
         endif
; no check to see if loc15in exists, because of check above on REF table
; section to put date in loc15in of BIB table
     @2,0 ? "Enter date of bibliographic reference:  "
     accept "d"       default today()     to refdate
     [loc15in] = refdate
     do_it!
     clear
     clearall
; section to put entry into REF table
        edit "ref"
        pickform 1
        end
        ctrlpgdn
        [beg_no] = begno
        wait record
            prompt "Press [F2] when done or [esc] to abort"
            until "F2", "esc"
            if retval = "F2" then
               [dirapp] = dirdate
               do_it!
               print file "diaryms" today(),"  ",begno,
                   " bibliographic reference entered, ",refdate,"\n"
               clear
               clearall
               loop
            endif
            if retval = "esc"
               then canceledit
               clear
               clearall
               loop
            endif
 case rout = "Change":
     edit "ref"
     moveto field "Beg_no"
     locate begno
       if not (retval) then
          @8,0 ? " *** ",begno," does not have bibliographic entry"
          sleep 2000
          canceledit
          clear
          loop
        else
          moveto field "Bib1"
          pickform 1
          editkey
          fieldview
          wait record
            prompt "Press [F2] when done or [esc] to abort"
            until "F2", "Esc"
            switch
               case retval = "F2":  do_it!
                   print file "diaryms" today(), " ",begno,"biblio edited \n"
                   clear
                   clearall
               case retval = "Esc":  canceledit
                   clear
                   clearall
                   quitloop
            endswitch
         loop
       endif
 case rout = "Number":
     edit "bib"
     moveto field "Beg_no"
     locate begno
         if not (retval) then
            style attribute 13
            @6,0 ? " *** ",begno," not in active database"
            sleep 2000
            canceledit
            clear
            loop
         else
            if not isblank([report_no]) then
               @8,0 ? " *** Report number already assigned:  ",[report_no]
               @10,0 ? "Do you want to change it? "
                accept "a1" to kans
                if kans = "Y" or kans ="y" then
                   @11,0 ? "Enter new report number:  "
                   accept "a10" to rpno
                   [report_no] = rpno
                   do_it!
                   clear
                else
                   canceledit
                   clear
                endif
            else
               @8,0 ? "Enter report number: "
               accept "a10" to rpno
               [report_no] = rpno
               do_it!
               clear
            endif
         endif
 case rout = "Return":
    return
endswitch
endwhile

ENDPROC

WRITELIB "TRACKLB" MSREFR1
RELEASE PROCS MSREFR1
;**************************
PROC MOV2AR1()
;  2/22/91
;This procedure moves the information about a manuscript from the BIB (active)
; table to the ARCH (archival) table.  It prompts for the manuscript number,
; displays the information about the manuscript and asks if it is the
; correct manuscript.  If it is, it moves all information to the ARCH table,
; and deletes the record from the BIB table.
;
while (true)
;GET VALUE FOR VARIABLE BEGNO
    style attribute 32
    @0,0 ?"MOVE MS TO ARCHIVAL:  Enter BG number:  "
    accept "a5" to bno
       if isblank(bno)
         then clearall
              return
       else
          begno="BG"+bno
       endif
     view "bib"
     moveto field "Beg_no"
     LOCATE begno
        if not (retval) then
           style attribute 13
           @6,0 ?  " *** ",begno," not in active database"
           sleep 2000
           clear
           return
        endif
           if not isblank ([loc15in]) then
              pickform 2
              wait record
            prompt " Press [F2] if this is the manuscript to move to archival;",
                   " Press [Esc] if it is not"
              until "F2", "Esc"
              switch
                  case retval = "Esc":
                     clear
                     clearall
                     return
                  case retval = "F2":
                     copytoarray M
                        edit "arch"
                        ins
                        copyfromarray M
                        do_it!
                        clearimage
; this should now be back to bib table to delete record
                     edit "bib"
                     del
                     do_it!
                     clear
                     clearall
                     @10,0 ? "Manuscript moved"   sleep 3000
                     clear
              endswitch
           else
            @6,0 ?" Manuscript does not have date for bibliographic reference"
            @7,0 ?" added; so is not an archival manuscript."
            sleep 3000
            clearall
           endif
endwhile
ENDPROC

WRITELIB "TRACKLB" MOV2AR1
RELEASE PROCS MOV2AR1

;**************************
